@@ -57,14 +57,20 @@ public:
 
     virtual void setZoomToFit(bool) Q_DECL_OVERRIDE;
 
+    virtual void setZoomToFitWidth(bool) Q_DECL_OVERRIDE;
+
     virtual bool zoomToFit() const Q_DECL_OVERRIDE;
 
+    virtual bool zoomToFitWidth() const Q_DECL_OVERRIDE;
+
     virtual qreal zoom() const Q_DECL_OVERRIDE;
 
     virtual void setZoom(qreal zoom, const QPointF& center) Q_DECL_OVERRIDE;
 
     virtual qreal computeZoomToFit() const Q_DECL_OVERRIDE;
 
+    virtual qreal computeZoomToFitWidth() const Q_DECL_OVERRIDE;
+
     virtual Document::Ptr document() const Q_DECL_OVERRIDE;
 
     virtual void setDocument(Document::Ptr) Q_DECL_OVERRIDE;
